{{ '=' * (project|length) }}==========================
{{              project   }} - Yet another tool to ...
{{ '=' * (project|length) }}==========================

{{project}} is a Python 3 ...

**Contents:**

.. toctree::
   :maxdepth: 2

   intro



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

